summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/forms/widgets/kexidbcombobox.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kexi/plugins/forms/widgets/kexidbcombobox.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/plugins/forms/widgets/kexidbcombobox.h')
-rw-r--r--kexi/plugins/forms/widgets/kexidbcombobox.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kexi/plugins/forms/widgets/kexidbcombobox.h b/kexi/plugins/forms/widgets/kexidbcombobox.h
index 2639b1f9..4e780aa3 100644
--- a/kexi/plugins/forms/widgets/kexidbcombobox.h
+++ b/kexi/plugins/forms/widgets/kexidbcombobox.h
@@ -44,7 +44,7 @@ class KEXIFORMUTILS_EXPORT KexiDBComboBox :
TQ_OVERRIDE(bool autoCaption DESIGNABLE false)
public:
- KexiDBComboBox(TQWidget *tqparent, const char *name=0, bool designMode = true);
+ KexiDBComboBox(TQWidget *parent, const char *name=0, bool designMode = true);
virtual ~KexiDBComboBox();
//! Implemented for KexiComboBoxBase: form has no 'related data' model (only the full database model)
@@ -147,7 +147,7 @@ class KEXIFORMUTILS_EXPORT KexiDBComboBox :
//! Implemented for KexiComboBoxBase
virtual void acceptRequested();
//! Implement this to return a position \a pos mapped from tqparent (e.g. viewport)
//! to global coordinates. TQPoint(-1, -1) should be returned if this cannot be computed.
virtual TQPoint mapFromParentToGlobal(const TQPoint& pos) const;
@@ -147,7 +147,7 @@ class KEXIFORMUTILS_EXPORT KexiDBComboBox :
//! Implemented for KexiComboBoxBase
virtual void acceptRequested();
- //! Implement this to return a position \a pos mapped from tqparent (e.g. viewport)
+ //! Implement this to return a position \a pos mapped from parent (e.g. viewport)
//! to global coordinates. TQPoint(-1, -1) should be returned if this cannot be computed.
virtual TQPoint mapFromParentToGlobal(const TQPoint& pos) const;